==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-cpuload/translations/cpuload_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="127"/>
        <source>CPU load %1%</source>
        <translation>Processorbelasting %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Processorbelasting-instellingen</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Tekst tonen</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Bijwerktussenpoos:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Balkrichting:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Balkbreedte:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="64"/>
        <source>Bottom up</source>
        <translation>Van onder naar boven</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="65"/>
        <source>Top down</source>
        <translation>Van boven naar onder</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="66"/>
        <source>Left to right</source>
        <translation>Van links naar rechts</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="67"/>
        <source>Right to left</source>
        <translation>Van rechts naar links</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1-1.src.tar.gz: lxqt-panel-2.2.1/plugin-cpuload/translations/cpuload_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <location filename="../lxqtcpuload.cpp" line="126"/>
        <source>CPU load %1%</source>
        <translation>Processorbelasting %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Instellingen voor processorbelasting</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Tekst tonen</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Bijwerkinterval:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Balkrichting:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Balkbreedte:</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="64"/>
        <source>Bottom up</source>
        <translation>Van onder naar boven</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="65"/>
        <source>Top down</source>
        <translation>Van boven naar onder</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="66"/>
        <source>Left to right</source>
        <translation>Van links naar rechts</translation>
    </message>
    <message>
        <location filename="../lxqtcpuloadconfiguration.cpp" line="67"/>
        <source>Right to left</source>
        <translation>Van rechts naar links</translation>
    </message>
</context>
</TS>
